@@ -8,17 +8,24 @@ raven.contrib.django.raven.management
 from __future__ import absolute_import, print_function
 
 import sys
+import warnings
 
 from functools import wraps
 
-from django.conf import settings
 
-
-def patch_base_command(cls):
+def patch_cli_runner():
     """
     Patches ``cls.execute``, returning a boolean describing if the
     attempt was successful.
     """
+    try:
+        from django.core.management import ManagementUtility
+    except ImportError:
+        warnings.warn('Unable to patch Django management commands')
+        return
+    else:
+        cls = ManagementUtility
+
     try:
         original_func = cls.execute
     except AttributeError:
@@ -28,35 +35,19 @@ def patch_base_command(cls):
     if hasattr(original_func, '__raven_patched'):
         return False
 
-    def can_capture(cls):
-        return 'sentry' not in settings.INSTALLED_APPS
-
     @wraps(original_func)
     def new_execute(self, *args, **kwargs):
         try:
             return original_func(self, *args, **kwargs)
         except Exception:
+            from raven.contrib.django.models import client
 
-            if can_capture(type(self)):
-                from raven.contrib.django.models import client
-
-                client.captureException(extra={
-                    'argv': sys.argv
-                })
+            client.captureException(extra={
+                'argv': sys.argv
+            })
             raise
 
     new_execute.__raven_patched = True
     cls.execute = new_execute
 
     return True
-
-if ('raven.contrib.django' in settings.INSTALLED_APPS
-        or 'raven.contrib.django.raven_compat' in settings.INSTALLED_APPS):
-
-    try:
-        from django.core.management.base import BaseCommand
-    except ImportError:
-        # give up
-        pass
-    else:
-        patch_base_command(BaseCommand)
