@@ -94,7 +94,7 @@ class Sentry(object):
     # TODO(dcramer): the client isn't using local context and therefore
     # gets shared by every app that does init on it
     def __init__(self, app=None, client=None, client_cls=Client, dsn=None,
-                 logging=False, level=logging.NOTSET, wrap_wsgi=True,
+                 logging=False, level=logging.NOTSET, wrap_wsgi=None,
                  register_signal=True):
         self.dsn = dsn
         self.logging = logging
@@ -191,8 +191,9 @@ class Sentry(object):
         self.client.http_context(self.get_http_info(request))
         self.client.user_context(self.get_user_info(request))
 
-    def add_sentry_id_header(self, sender, response, *args, **kwargs):
+    def after_request(self, sender, response, *args, **kwargs):
         response.headers['X-Sentry-ID'] = self.last_event_id
+        self.client.context.clear()
         return response
 
     def init_app(self, app, dsn=None, logging=None, level=None, wrap_wsgi=None,
@@ -205,6 +206,13 @@ class Sentry(object):
 
         if wrap_wsgi is not None:
             self.wrap_wsgi = wrap_wsgi
+        else:
+            # Fix https://github.com/getsentry/raven-python/issues/412
+            # the gist is that we get errors twice in debug mode if we don't do this
+            if app and app.debug:
+                self.wrap_wsgi = False
+            else:
+                self.wrap_wsgi = True
 
         if register_signal is not None:
             self.register_signal = register_signal
@@ -225,7 +233,7 @@ class Sentry(object):
 
         if self.register_signal:
             got_request_exception.connect(self.handle_exception, sender=app)
-            request_finished.connect(self.add_sentry_id_header, sender=app)
+            request_finished.connect(self.after_request, sender=app)
 
         if not hasattr(app, 'extensions'):
             app.extensions = {}
@@ -248,3 +256,15 @@ class Sentry(object):
         else:
             self.last_event_id = None
         return result
+
+    def user_context(self, *args, **kwargs):
+        assert self.client, 'user_context called before application configured'
+        return self.client.user_context(*args, **kwargs)
+
+    def tags_context(self, *args, **kwargs):
+        assert self.client, 'tags_context called before application configured'
+        return self.client.tags_context(*args, **kwargs)
+
+    def extra_context(self, *args, **kwargs):
+        assert self.client, 'extra_context called before application configured'
+        return self.client.extra_context(*args, **kwargs)
