@@ -34,6 +34,9 @@ class Processor(object):
         if 'request' in data:
             self.filter_http(data['request'])
 
+        if 'extra' in data:
+            data['extra'] = self.filter_extra(data['extra'])
+
         return data
 
     def filter_stacktrace(self, data):
@@ -42,6 +45,9 @@ class Processor(object):
     def filter_http(self, data):
         pass
 
+    def filter_extra(self, data):
+        return data
+
 
 class RemovePostDataProcessor(Processor):
     """
@@ -67,7 +73,13 @@ class SanitizePasswordsProcessor(Processor):
     """
     MASK = '*' * 8
     FIELDS = frozenset([
-        'password', 'secret', 'passwd', 'authorization', 'api_key', 'apikey'
+        'password',
+        'secret',
+        'passwd',
+        'authorization',
+        'api_key',
+        'apikey',
+        'sentry_dsn',
     ])
     VALUES_RE = re.compile(r'^(?:\d[ -]*?){13,16}$')
 
@@ -115,6 +127,9 @@ class SanitizePasswordsProcessor(Processor):
                         data[n]['Cookie'], ';'
                     )
 
+    def filter_extra(self, data):
+        return varmap(self.sanitize, data)
+
     def _sanitize_keyvals(self, keyvals, delimiter):
         sanitized_keyvals = []
         for keyval in keyvals.split(delimiter):
