@@ -3,10 +3,9 @@ from __future__ import unicode_literals
 
 import inspect
 import mock
-import pytest
 import raven
 import time
-from socket import socket, AF_INET, SOCK_DGRAM
+
 from raven.base import Client, ClientState
 from raven.exceptions import RateLimited
 from raven.transport import AsyncTransport
@@ -105,12 +104,12 @@ class ClientTest(TestCase):
 
         # test error
         send.side_effect = Exception()
-        client.send_remote('sync+http://example.com/api/store', 'foo')
+        client.send_remote('sync+http://example.com/api/store', client.encode({}))
         self.assertEquals(client.state.status, client.state.ERROR)
 
         # test recovery
         send.side_effect = None
-        client.send_remote('sync+http://example.com/api/store', 'foo')
+        client.send_remote('sync+http://example.com/api/store', client.encode({}))
         self.assertEquals(client.state.status, client.state.ONLINE)
 
     @mock.patch('raven.transport.http.HTTPTransport.send')
@@ -124,13 +123,13 @@ class ClientTest(TestCase):
 
         # test error
         send.side_effect = RateLimited('foo', 5)
-        client.send_remote('sync+http://example.com/api/store', 'foo')
+        client.send_remote('sync+http://example.com/api/store', client.encode({}))
         self.assertEquals(client.state.status, client.state.ERROR)
         self.assertEqual(client.state.retry_after, 5)
 
         # test recovery
         send.side_effect = None
-        client.send_remote('sync+http://example.com/api/store', 'foo')
+        client.send_remote('sync+http://example.com/api/store', client.encode({}))
         self.assertEquals(client.state.status, client.state.ONLINE)
         self.assertEqual(client.state.retry_after, 0)
 
@@ -151,17 +150,17 @@ class ClientTest(TestCase):
 
         # test immediate raise of error
         async_send.side_effect = Exception()
-        client.send_remote('http://example.com/api/store', 'foo')
+        client.send_remote('http://example.com/api/store', client.encode({}))
         self.assertEquals(client.state.status, client.state.ERROR)
 
         # test recovery
-        client.send_remote('http://example.com/api/store', 'foo')
+        client.send_remote('http://example.com/api/store', client.encode({}))
         success_cb = async_send.call_args[0][2]
         success_cb()
         self.assertEquals(client.state.status, client.state.ONLINE)
 
         # test delayed raise of error
-        client.send_remote('http://example.com/api/store', 'foo')
+        client.send_remote('http://example.com/api/store', client.encode({}))
         failure_cb = async_send.call_args[0][3]
         failure_cb(Exception())
         self.assertEquals(client.state.status, client.state.ERROR)
@@ -171,23 +170,20 @@ class ClientTest(TestCase):
     def test_send(self, time, send_remote):
         time.return_value = 1328055286.51
         client = Client(
-            servers=['http://example.com'],
-            public_key='public',
-            secret_key='secret',
-            project=1,
+            dsn='http://public:secret@example.com/1',
         )
         client.send(**{
             'foo': 'bar',
         })
         send_remote.assert_called_once_with(
-            url='http://example.com',
+            url='http://example.com/api/1/store/',
             data=six.b('eJyrVkrLz1eyUlBKSixSqgUAIJgEVA=='),
             headers={
                 'User-Agent': 'raven-python/%s' % (raven.VERSION,),
                 'Content-Type': 'application/octet-stream',
                 'X-Sentry-Auth': (
                     'Sentry sentry_timestamp=1328055286.51, '
-                    'sentry_client=raven-python/%s, sentry_version=5, '
+                    'sentry_client=raven-python/%s, sentry_version=6, '
                     'sentry_key=public, '
                     'sentry_secret=secret' % (raven.VERSION,))
             },
@@ -198,16 +194,13 @@ class ClientTest(TestCase):
     def test_send_with_auth_header(self, time, send_remote):
         time.return_value = 1328055286.51
         client = Client(
-            servers=['http://example.com'],
-            public_key='public',
-            secret_key='secret',
-            project=1,
+            dsn='http://public:secret@example.com/1',
         )
         client.send(auth_header='foo', **{
             'foo': 'bar',
         })
         send_remote.assert_called_once_with(
-            url='http://example.com',
+            url='http://example.com/api/1/store/',
             data=six.b('eJyrVkrLz1eyUlBKSixSqgUAIJgEVA=='),
             headers={
                 'User-Agent': 'raven-python/%s' % (raven.VERSION,),
@@ -221,10 +214,7 @@ class ClientTest(TestCase):
     def test_raise_exception_on_send_error(self, should_try, _send_remote):
         should_try.return_value = True
         client = Client(
-            servers=['sync+http://example.com'],
-            public_key='public',
-            secret_key='secret',
-            project=1,
+            dsn='sync+http://public:secret@example.com/1',
         )
 
         # Test for the default behaviour in which a send error is handled by the client
@@ -235,10 +225,7 @@ class ClientTest(TestCase):
 
         # Test for the case in which a send error is raised to the calling frame.
         client = Client(
-            servers=['sync+http://example.com'],
-            public_key='public',
-            secret_key='secret',
-            project=1,
+            dsn='sync+http://public:secret@example.com/1',
             raise_send_errors=True,
         )
         with self.assertRaises(Exception):
@@ -476,23 +463,3 @@ class ClientTest(TestCase):
         else:
             expected = {'logger': "u'test'", 'foo': "u'bar'"}
         self.assertEquals(event['extra'], expected)
-
-
-# TODO: Python 3
-@pytest.mark.skipif(str("six.PY3"))
-class ClientUDPTest(TestCase):
-    def setUp(self):
-        self.server_socket = socket(AF_INET, SOCK_DGRAM)
-        self.server_socket.bind(('127.0.0.1', 0))
-        self.client = Client(servers=["udp://%s:%s" % self.server_socket.getsockname()], key='BassOmatic')
-
-    def test_delivery(self):
-        self.client.captureMessage('test')
-        data, address = self.server_socket.recvfrom(2 ** 16)
-        self.assertTrue("\n\n" in data)
-        header, payload = data.split("\n\n")
-        for substring in ("sentry_timestamp=", "sentry_client="):
-            self.assertTrue(substring in header)
-
-    def tearDown(self):
-        self.server_socket.close()
